<?php

/**
 * UIU CSE functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package UIU_CSE
 */

if (!defined('_S_VERSION')) {
	// Replace the version number of the theme on each release.
	define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function uiu_cse_setup()
{
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on UIU CSE, use a find and replace
		* to change 'uiu-cse' to the name of your theme in all the template files.
		*/
	load_theme_textdomain('uiu-cse', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support('title-tag');

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__('Primary', 'uiu-cse'),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'uiu_cse_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
}
add_action('after_setup_theme', 'uiu_cse_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function uiu_cse_content_width()
{
	$GLOBALS['content_width'] = apply_filters('uiu_cse_content_width', 640);
}
add_action('after_setup_theme', 'uiu_cse_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function uiu_cse_widgets_init()
{
	register_sidebar(
		array(
			'name'          => esc_html__('Sidebar', 'uiu-cse'),
			'id'            => 'sidebar-1',
			'description'   => esc_html__('Add widgets here.', 'uiu-cse'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action('widgets_init', 'uiu_cse_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function uiu_cse_scripts()
{
	wp_enqueue_style('uiu-cse-style', get_stylesheet_uri(), array(), _S_VERSION);
	wp_style_add_data('uiu-cse-style', 'rtl', 'replace');

	wp_enqueue_style('uiu-cse-pickr', 'https://cdn.jsdelivr.net/npm/@simonwep/pickr/dist/themes/nano.min.css');

	wp_enqueue_style('uiu-cse-google-fonts-material-icon', 'https://fonts.googleapis.com/icon?family=Material+Icons');

	wp_enqueue_style('uiu-cse-google-fonts-material-symbols-outlined', 'https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@48,400,0,0');

	wp_enqueue_style('uiu-cse-google-fonts-material+symbols+sharpt', 'https://fonts.googleapis.com/css2?family=Material+Symbols+Sharp:opsz,wght,FILL,GRAD@48,400,0,0');

	wp_enqueue_script('uiu-cse-pickr-js', 'https://cdn.jsdelivr.net/npm/@simonwep/pickr/dist/pickr.min.js', array(), '');

	wp_enqueue_script('uiu-cse-settings-js', get_template_directory_uri() . '/js/theme-settings.js', array(), _S_VERSION, true);

	wp_enqueue_script('uiu-cse-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'uiu_cse_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}


/**
 * Theme option and custom fields settings
 */
// Custom Blocks
include_once(get_stylesheet_directory() . '/inc/custom-blocks.php');

// ACF
include_once(get_template_directory() . '/inc/acf/acf.php');

// ACF Settings
include_once(get_template_directory() . '/inc/acf-settings.php');

// Custom post type
include_once(get_stylesheet_directory() . '/inc/custom-post-type.php');

// Typeahead Settings
// include_once( get_stylesheet_directory() . '/inc/wp-typeahead.php');

// Widgets
// include_once( get_stylesheet_directory() . '/inc/widgets.php' );

// Menus
// include_once( get_stylesheet_directory() . '/inc/menus.php' );

// Theme Settings
include_once(get_stylesheet_directory() . '/inc/theme-settings.php');

// Shortcodes
// include_once( get_stylesheet_directory() . '/inc/shortcodes.php' );


// Fetch vimeo thumbnail on save - takes video ID as input
function uiu_acf_update_user_id($value, $post_id, $field)
{
	// only set a new value if the field is empty
	// if ($value == '') {
	// get video here
	$login_id = get_field('login_id');
	// fetch thumb url(s)
	$user_meta = file_get_contents("https://api.github.com/users/rousnay");
	$user_meta = json_decode($user_meta);
	$user_id = $user_meta[0]->id;
	// set value
	$value = "Rousnay";
	return $value;
	// } else {
	// 	return $value;
	// }
}

add_filter('acf/update_value/name=employeeid', 'uiu_acf_update_user_id', 10, 3);
